@@ -120,7 +120,8 @@ class GPTScore(Metric):
                 value += score
             else:
                 no_score += 1
-        value = value / (len(scores) - no_score)
+
+        value = 0 if len(scores) - no_score == 0 else value / (len(scores) - no_score)
         return {
             "value": value,
             "no_score": no_score,
@@ -339,6 +340,13 @@ _GPT_METRICS: [str, Metric] = {
             criteria="grammar",
         ),
     ),
+    "generic_bool/harmlessness": GPTScore(
+        GPTScoreConfig(
+            name="generic_bool/harmlessness",
+            protocol_config_path=os.path.join(PROTOCOLS_PATH, "generic_bool.yaml"),
+            criteria="harmlessness",
+        ),
+    ),
     "generic_likert/helpfulness": GPTScore(
         GPTScoreConfig(
             name="generic_likert/helpfulness",
@@ -360,6 +368,13 @@ _GPT_METRICS: [str, Metric] = {
             criteria="coherence",
         ),
     ),
+    "generic_likert/harmlessness": GPTScore(
+        GPTScoreConfig(
+            name="generic_likert/harmlessness",
+            protocol_config_path=os.path.join(PROTOCOLS_PATH, "generic_likert.yaml"),
+            criteria="harmlessness",
+        ),
+    ),
     "generic_pairwise/helpfulness": GPTScore(
         GPTScoreConfig(
             name="generic_pairwise/coherence",
@@ -381,6 +396,13 @@ _GPT_METRICS: [str, Metric] = {
             criteria="coherence",
         ),
     ),
+    "generic_pairwise/harmlessness": GPTScore(
+        GPTScoreConfig(
+            name="generic_pairwise/harmlessness",
+            protocol_config_path=os.path.join(PROTOCOLS_PATH, "generic_pairwise.yaml"),
+            criteria="harmlessness",
+        ),
+    ),
     "generic_rank/helpfulness": GPTScore(
         GPTScoreConfig(
             name="generic_rank/helpfulness",
@@ -402,4 +424,11 @@ _GPT_METRICS: [str, Metric] = {
             criteria="coherence",
         ),
     ),
+    "generic_rank/harmlessness": GPTScore(
+        GPTScoreConfig(
+            name="generic_rank/harmlessness",
+            protocol_config_path=os.path.join(PROTOCOLS_PATH, "generic_rank.yaml"),
+            criteria="harmlessness",
+        ),
+    ),
 }
